@@ -34,13 +34,16 @@ _tests = []
 
 # Gather tests from this directory
 import pkgutil
+import importlib
+
 for finder, mod_name, _ispkg in pkgutil.iter_modules(__path__):
     # Skip __main__
     if mod_name == "__main__":
         continue
 
     # Load the module
-    module = finder.find_module(mod_name).load_module(mod_name)
+    full_name = "{}.{}".format(__name__, mod_name)
+    module = importlib.import_module(full_name)
 
     # Look for attributes that start with 'test_' and add them to the test list
     for attrname, attr in module.__dict__.items():
